@@ -56,34 +56,34 @@ SEXP git2r_merge_base(SEXP one, SEXP two)
     git_repository *repository = NULL;
 
     if (git2r_arg_check_commit(one))
-        git2r_error(git2r_err_commit_arg, __func__, "one");
+        git2r_error(__func__, NULL, "'one'", git2r_err_commit_arg);
     if (git2r_arg_check_commit(two))
-        git2r_error(git2r_err_commit_arg, __func__, "two");
+        git2r_error(__func__, NULL, "'two'", git2r_err_commit_arg);
 
     repo = GET_SLOT(one, Rf_install("repo"));
     repository = git2r_repository_open(repo);
     if (!repository)
-        git2r_error(git2r_err_invalid_repository, __func__, NULL);
+        git2r_error(__func__, NULL, git2r_err_invalid_repository, NULL);
 
     sha = GET_SLOT(one, Rf_install("sha"));
     err = git_oid_fromstr(&oid_one, CHAR(STRING_ELT(sha, 0)));
-    if (GIT_OK != err)
+    if (err)
         goto cleanup;
 
     sha = GET_SLOT(two, Rf_install("sha"));
     err = git_oid_fromstr(&oid_two, CHAR(STRING_ELT(sha, 0)));
-    if (GIT_OK != err)
+    if (err)
         goto cleanup;
 
     err = git_merge_base(&oid, repository, &oid_one, &oid_two);
-    if (GIT_OK != err) {
+    if (err) {
         if (GIT_ENOTFOUND == err)
             err = GIT_OK;
         goto cleanup;
     }
 
     err = git_commit_lookup(&commit, repository, &oid);
-    if (GIT_OK != err)
+    if (err)
         goto cleanup;
 
     PROTECT(result = NEW_OBJECT(MAKE_CLASS("git_commit")));
@@ -99,8 +99,8 @@ cleanup:
     if (R_NilValue != result)
         UNPROTECT(1);
 
-    if (GIT_OK != err)
-        git2r_error(git2r_err_from_libgit2, __func__, giterr_last()->message);
+    if (err)
+        git2r_error(__func__, giterr_last(), NULL, NULL);
 
     return result;
 }
@@ -130,26 +130,26 @@ static int git2r_fast_forward_merge(
 
     oid = git_annotated_commit_id(merge_head);
     err = git_commit_lookup(&commit, repository, oid);
-    if (GIT_OK != err)
+    if (err)
         goto cleanup;
 
     err = git_commit_tree(&tree, commit);
-    if (GIT_OK != err)
+    if (err)
         goto cleanup;
 
     opts.checkout_strategy = GIT_CHECKOUT_SAFE;
     err = git_checkout_tree(repository, (git_object*)tree, &opts);
-    if (GIT_OK != err)
+    if (err)
         goto cleanup;
 
     err = git_repository_head(&reference, repository);
-    if (GIT_OK != err) {
+    if (err) {
         if (GIT_ENOTFOUND != err)
             goto cleanup;
     }
 
     err = git_buf_printf(&buf, "%s: Fast-forward", log_message);
-    if (GIT_OK != err)
+    if (err)
         goto cleanup;
 
     if (GIT_ENOTFOUND == err) {
@@ -234,11 +234,11 @@ static int git2r_normal_merge(
         n,
         merge_opts,
         checkout_opts);
-    if (GIT_OK != err)
+    if (err)
         goto cleanup;
 
     err = git_repository_index(&index, repository);
-    if (GIT_OK != err)
+    if (err)
         goto cleanup;
 
     if (git_index_has_conflicts(index)) {
@@ -257,7 +257,7 @@ static int git2r_normal_merge(
                 message,
                 merger,
                 merger);
-            if (GIT_OK != err)
+            if (err)
                 goto cleanup;
 
             git_oid_fmt(sha, &oid);
@@ -316,7 +316,7 @@ static int git2r_merge(
         repository,
         merge_heads,
         n);
-    if (GIT_OK != err)
+    if (err)
         return err;
 
     if (merge_analysis & GIT_MERGE_ANALYSIS_UP_TO_DATE) {
@@ -448,24 +448,24 @@ SEXP git2r_merge_branch(SEXP branch, SEXP merger, SEXP commit_on_success)
     git_signature *who = NULL;
 
     if (git2r_arg_check_branch(branch))
-        git2r_error(git2r_err_branch_arg, __func__, "branch");
+        git2r_error(__func__, NULL, "'branch'", git2r_err_branch_arg);
     if (git2r_arg_check_logical(commit_on_success))
-        git2r_error(git2r_err_logical_arg, __func__, "commit_on_success");
+        git2r_error(__func__, NULL, "'commit_on_success'", git2r_err_logical_arg);
     if (git2r_arg_check_signature(merger))
-        git2r_error(git2r_err_signature_arg, __func__, "merger");
+        git2r_error(__func__, NULL, "'merger'", git2r_err_signature_arg);
 
     err = git2r_signature_from_arg(&who, merger);
-    if (GIT_OK != err)
+    if (err)
         goto cleanup;
 
     repository = git2r_repository_open(GET_SLOT(branch, Rf_install("repo")));
     if (!repository)
-        git2r_error(git2r_err_invalid_repository, __func__, NULL);
+        git2r_error(__func__, NULL, git2r_err_invalid_repository, NULL);
 
     name = CHAR(STRING_ELT(GET_SLOT(branch, Rf_install("name")), 0));
     type = INTEGER(GET_SLOT(branch, Rf_install("type")))[0];
     err = git_branch_lookup(&reference, repository, name, type);
-    if (GIT_OK != err)
+    if (err)
         goto cleanup;
 
     merge_heads = calloc(1, sizeof(git_annotated_commit*));
@@ -478,11 +478,11 @@ SEXP git2r_merge_branch(SEXP branch, SEXP merger, SEXP commit_on_success)
         &(merge_heads[0]),
         repository,
         reference);
-    if (GIT_OK != err)
+    if (err)
         goto cleanup;
 
     err = git_buf_printf(&buf, "merge %s", name);
-    if (GIT_OK != err)
+    if (err)
         goto cleanup;
 
     PROTECT(result = NEW_OBJECT(MAKE_CLASS("git_merge_result")));
@@ -514,8 +514,8 @@ cleanup:
     if (R_NilValue != result)
         UNPROTECT(1);
 
-    if (GIT_OK != err)
-        git2r_error(git2r_err_from_libgit2, __func__, giterr_last()->message);
+    if (err)
+        git2r_error(__func__, giterr_last(), NULL, NULL);
 
     return result;
 }
@@ -553,7 +553,7 @@ static int git2r_merge_heads_from_fetch_heads(
         err = git_oid_fromstr(
             &oid,
             CHAR(STRING_ELT(GET_SLOT(fh, Rf_install("sha")), 0)));
-        if (GIT_OK != err)
+        if (err)
             goto cleanup;
 
         err = git_annotated_commit_from_fetchhead(
@@ -562,12 +562,12 @@ static int git2r_merge_heads_from_fetch_heads(
             CHAR(STRING_ELT(GET_SLOT(fh, Rf_install("ref_name")), 0)),
             CHAR(STRING_ELT(GET_SLOT(fh, Rf_install("remote_url")), 0)),
             &oid);
-        if (GIT_OK != err)
+        if (err)
             goto cleanup;
     }
 
 cleanup:
-    if (GIT_OK != err) {
+    if (err) {
         if (*merge_heads)
             git2r_merge_heads_free(*merge_heads, n);
         *merge_heads = NULL;
@@ -594,12 +594,12 @@ SEXP git2r_merge_fetch_heads(SEXP fetch_heads, SEXP merger)
     git_signature *who = NULL;
 
     if (git2r_arg_check_fetch_heads(fetch_heads))
-        git2r_error(git2r_err_fetch_heads_arg, __func__, "fetch_heads");
+        git2r_error(__func__, NULL, "'fetch_heads'", git2r_err_fetch_heads_arg);
     if (git2r_arg_check_signature(merger))
-        git2r_error(git2r_err_signature_arg, __func__, "merger");
+        git2r_error(__func__, NULL, "'merger'", git2r_err_signature_arg);
 
     err = git2r_signature_from_arg(&who, merger);
-    if (GIT_OK != err)
+    if (err)
         goto cleanup;
 
     n = LENGTH(fetch_heads);
@@ -607,7 +607,7 @@ SEXP git2r_merge_fetch_heads(SEXP fetch_heads, SEXP merger)
         SEXP repo = GET_SLOT(VECTOR_ELT(fetch_heads, 0), Rf_install("repo"));
         repository = git2r_repository_open(repo);
         if (!repository)
-            git2r_error(git2r_err_invalid_repository, __func__, NULL);
+            git2r_error(__func__, NULL, git2r_err_invalid_repository, NULL);
     }
 
     err = git2r_merge_heads_from_fetch_heads(
@@ -615,7 +615,7 @@ SEXP git2r_merge_fetch_heads(SEXP fetch_heads, SEXP merger)
         repository,
         fetch_heads,
         n);
-    if (GIT_OK != err)
+    if (err)
         goto cleanup;
 
     PROTECT(result = NEW_OBJECT(MAKE_CLASS("git_merge_result")));
@@ -628,7 +628,7 @@ SEXP git2r_merge_fetch_heads(SEXP fetch_heads, SEXP merger)
         "pull",
         who,
         1); /* Commit on success */
-    if (GIT_OK != err)
+    if (err)
         goto cleanup;
 
 cleanup:
@@ -644,8 +644,8 @@ cleanup:
     if (R_NilValue != result)
         UNPROTECT(1);
 
-    if (GIT_OK != err)
-        git2r_error(git2r_err_from_libgit2, __func__, giterr_last()->message);
+    if (err)
+        git2r_error(__func__, giterr_last(), NULL, NULL);
 
     return result;
 }
